@@ -41,13 +41,13 @@ from ctypes import *
 path = os.path.dirname(os.path.realpath(__file__))
 
 try:
-    spreadsheet_c = CDLL("{}/spreadsheet_c.cpython-38-darwin.so".format(path))
-    reverse_spreadsheet = CDLL("{}/reverse_spreadsheet.cpython-38-darwin.so".format(path))
-    TFIDF_max = CDLL("{}/TFIDF_max.cpython-38-darwin.so".format(path))
-    null_parameters = CDLL("{}/null_parameters.cpython-38-darwin.so".format(path))
-    certainty_search = CDLL("{}/certainty_search.cpython-38-darwin.so".format(path))
-    radius_arr = CDLL("{}/radius_arr.cpython-38-darwin.so".format(path))
-    TFIDF_max_elastic = CDLL("{}/TFIDF_max_elastic.cpython-38-darwin.so".format(path))
+    spreadsheet_c = cdll.LoadLibrary("{}/spreadsheet_c.cpython-38-darwin.so".format(path))
+    reverse_spreadsheet = cdll.LoadLibrary("reverse_spreadsheet.cpython-38-darwin.so".format(path))
+    TFIDF_max = cdll.LoadLibrary("TFIDF_max.cpython-38-darwin.so".format(path))
+    null_parameters = cdll.LoadLibrary("null_parameters.cpython-38-darwin.so".format(path))
+    certainty_search = cdll.LoadLibrary("certainty_search.cpython-38-darwin.so".format(path))
+    radius_arr = cdll.LoadLibrary("radius_arr.cpython-38-darwin.so".format(path))
+    TFIDF_max_elastic = cdll.LoadLibrary("TFIDF_max_elastic.cpython-38-darwin.so".format(path))
 except:
     from places_geocode.app.CythonOperations import spreadsheet_c, reverse_spreadsheet, TFIDF_max, null_parameters, TFIDF_max_elastic, certainty_search, radius_arr
 
