@@ -3,8 +3,8 @@ from typing import List, Optional, Union, Type, Tuple, Any, Callable, Dict
 from abc import ABC, abstractmethod
 import sys
 import nltk
-#nltk.download('stopwords')
-#nltk.download('wordnet')
+nltk.download('stopwords')
+nltk.download('wordnet')
 from nltk.corpus import stopwords
 from nltk.stem import WordNetLemmatizer
 import threading
