@@ -40,16 +40,16 @@ path = os.path.dirname(os.path.realpath(__file__))
 # import cython files
 from ctypes import *
 try:
-    create_convex_array = cdll.LoadLibrary("{}/create_convex_array.cpython-38-darwin.so".format(path))
-    check_dups = cdll.LoadLibrary("{}/check_dups.cpython-38-darwin.so".format(path))
-    zip_coordinate = cdll.LoadLibrary("{}/zip_coordinate.cpython-38-darwin.so".format(path))
-    check_lat_long_length = cdll.LoadLibrary("{}/check_lat_long_length.cpython-38-darwin.so".format(path))
-    check_address_length = cdll.LoadLibrary("{}/check_address_length.cpython-38-darwin.so".format(path))
-    zip_coordinates_elastic = cdll.LoadLibrary("{}/zip_coordinates_elastic.cpython-38-darwin.so".format(path))
-    create_convex_elastic = cdll.LoadLibrary("{}/create_convex_elastic.cpython-38-darwin.so".format(path))
-    coordinate_conv_package = cdll.LoadLibrary("{}/coordinate_conv_package.cpython-38-darwin.so".format(path))
+    create_convex_array = cdll.LoadLibrary("create_convex_array.cpython-38-darwin.so".format(path))
+    check_dups = cdll.LoadLibrary("check_dups.cpython-38-darwin.so".format(path))
+    zip_coordinate = cdll.LoadLibrary("zip_coordinate.cpython-38-darwin.so".format(path))
+    check_lat_long_length = cdll.LoadLibrary("check_lat_long_length.cpython-38-darwin.so".format(path))
+    check_address_length = cdll.LoadLibrary("check_address_length.cpython-38-darwin.so".format(path))
+    zip_coordinates_elastic = cdll.LoadLibrary("zip_coordinates_elastic.cpython-38-darwin.so".format(path))
+    create_convex_elastic = cdll.LoadLibrary("create_convex_elastic.cpython-38-darwin.so".format(path))
+    coordinate_conv_package = cdll.LoadLibrary("coordinate_conv_package.cpython-38-darwin.so".format(path))
 except:
-    from places_geocode.app.dprk_copy import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
+    from places_geocode.app.CythonOperations import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
         check_address_length, zip_coordinates_elastic, create_convex_elastic, coordinate_conv_package
 
 
